@@ -32,6 +32,7 @@
 #include "file-utils.h"
 
 #include "thumbnail-manager.h"
+#include "global-settings.h"
 
 #include "file-operation-utils.h"
 
@@ -40,8 +41,9 @@
 #include <QUrl>
 
 #include <QTimer>
-
 #include <QDebug>
+#include <QDateTime>
+#include <QGSettings>
 
 using namespace Peony;
 
@@ -248,10 +250,12 @@ QVariant FileItemModel::data(const QModelIndex &index, int role) const
     case ModifiedDate: {
         switch (role) {
         case Qt::DisplayRole:
-            //can not sort, comment this
             //trash files show delete Date
-//            if (m_root_uri.startsWith("trash://") && !item->m_info->deletionDate().isNull())
-//                return QVariant(item->m_info->deletionDate());
+            if (m_root_uri.startsWith("trash://") && !item->m_info->deletionDate().isNull()) {
+                QDateTime deleteTime = QDateTime::fromMSecsSinceEpoch(item->m_info->deletionTime (), Qt::LocalTime);
+                QString format = GlobalSettings::getInstance()->getSystemTimeFormat();
+                return QVariant(deleteTime.toString(format));
+            }
             return QVariant(item->m_info->modifiedDate());
         default:
             return QVariant();
@@ -298,10 +302,9 @@ QVariant FileItemModel::headerData(int section, Qt::Orientation orientation, int
         case FileName:
             return tr("File Name");
         case ModifiedDate:
-            //can not sort, comment this
             //trash files show delete Date
-//            if (m_root_uri.startsWith("trash:///"))
-//                return tr("Delete Date");
+            if (m_root_uri.startsWith("trash:///"))
+                return tr("Delete Date");
             return tr("Modified Date");
         case FileType:
             return tr("File Type");
@@ -499,10 +502,12 @@ bool FileItemModel::dropMimeData(const QMimeData *data, Qt::DropAction action, i
         //we have to set the dest dir uri as its mount point.
         //maybe i should do this when set model root item.
         destDirUri = m_root_item->m_info->uri();
-        auto targetUri = FileUtils::getTargetUri(destDirUri);
-        if (!targetUri.isEmpty()) {
-            destDirUri = targetUri;
-        }
+    }
+
+    //get real destDirUri
+    auto targetUri = FileUtils::getTargetUri(destDirUri);
+    if (!targetUri.isEmpty()) {
+        destDirUri = targetUri;
     }
 
     //if destDirUri was not set, do not execute a drop.
@@ -549,6 +554,16 @@ bool FileItemModel::dropMimeData(const QMimeData *data, Qt::DropAction action, i
         return false;
     }
 
+    //if drag file to empty CD or DVD, is invalid operation, link to bug#129347
+    //如果是拖拽文件到空光盘，操作无效，光盘只能刻录，不能直接写入文件
+    if (destDirUri.startsWith("burn:///"))
+        return false;
+
+    //can not move StandardPath to any dir
+    if (action == Qt::MoveAction && FileUtils::containsStandardPath(srcUris)) {
+        return false;
+    }
+
     bool b_trash_item = false;
     for(auto path : srcUris)
     {
@@ -565,12 +580,26 @@ bool FileItemModel::dropMimeData(const QMimeData *data, Qt::DropAction action, i
     //fix drag file to trash issue, #42328
     if (destDirUri.startsWith("trash:///"))
     {
-        FileOperationUtils::trash(srcUris, true);
+        // fix drag filesafe to trash error issue, #81938
+        if(!(srcUris.first().startsWith("filesafe:///") &&
+            (QString(srcUris.first()).remove("filesafe:///").indexOf("/") == -1))) {
+            FileOperationUtils::trash(srcUris, true);
+        }
         return true;
     }
 
     qDebug() << "dropMimeData:" <<action<<destDirUri;
     bool addHistory = true;
+    //krme files can not move to other place, default set as copy action
+    if (srcUris.first().startsWith("kmre:///") || srcUris.first().startsWith("kydroid:///"))
+        action = Qt::CopyAction;
+
+    //filesafe files can not move to other place, default set as copy action
+    if (srcUris.first().startsWith("filesafe:///") && destDirUri.startsWith("favorite:///"))
+        return false;
+    if (srcUris.first().startsWith("filesafe:///"))
+        action = Qt::CopyAction;
+
     auto op = FileOperationUtils::moveWithAction(srcUris, destDirUri, addHistory, action);
     connect(op, &FileOperation::operationFinished, this, [=](){
         auto opInfo = op->getOperationInfo();
@@ -593,7 +622,7 @@ bool FileItemModel::dropMimeData(const QMimeData *data, Qt::DropAction action, i
     return true;
 }
 
-void FileItemModel::sendPathChangeRequest(const QString &uri)
+void FileItemModel::sendPathChangeRequest(const QString &destUri, const QString &sourceUri)
 {
-    Q_EMIT this->changePathRequest(uri, true, true);
+    Q_EMIT this->changePathRequest(destUri, sourceUri);
 }
