@@ -52,6 +52,12 @@ FileItemProxyFilterSortModel::FileItemProxyFilterSortModel(QObject *parent) : QS
     comparer.setNumericMode(true);
     auto settings = GlobalSettings::getInstance();
     m_show_hidden = settings->isExist(SHOW_HIDDEN_PREFERENCE)? settings->getValue(SHOW_HIDDEN_PREFERENCE).toBool(): false;
+    connect(GlobalSettings::getInstance(), &GlobalSettings::valueChanged, this, [=] (const QString& key) {
+        if (SHOW_HIDDEN_PREFERENCE == key) {
+            m_show_hidden= GlobalSettings::getInstance()->getValue(key).toBool();
+            invalidateFilter();
+        }
+    });
     m_use_default_name_sort_order = settings->isExist(SORT_CHINESE_FIRST)? settings->getValue(SORT_CHINESE_FIRST).toBool(): false;
     m_folder_first = settings->isExist(SORT_FOLDER_FIRST)? settings->getValue(SORT_FOLDER_FIRST).toBool(): true;
 }
@@ -105,54 +111,95 @@ bool FileItemProxyFilterSortModel::lessThan(const QModelIndex &left, const QMode
         auto leftItem = model->itemFromIndex(left);
         auto rightItem = model->itemFromIndex(right);
         if (!(leftItem->hasChildren() && rightItem->hasChildren())) {
-            //make folder always has a higher order.
-            if (!leftItem->hasChildren() && !rightItem->hasChildren()) {
-                goto default_sort;
-            }
-            if (m_folder_first) {
+            //make folder always has a higher order
+            if ((leftItem->hasChildren() || rightItem->hasChildren()) && m_folder_first) {
                 bool lesser = leftItem->hasChildren();
                 if (sortOrder() == Qt::AscendingOrder)
                     return lesser;
                 return !lesser;
             }
+        }else if (sortColumn() != FileItemModel::ModifiedDate){
+            goto default_sort;
         }
 
-default_sort:
+        //fix bug#97408,change indicator meanings
+        //箭头向上为升序，向下为降序，与通常的理解对应，对比了UOS是这样的
+        //将所有排序对比跟之前的方式反过来，小于改为大于，返回true的改为false
         switch (sortColumn()) {
         case FileItemModel::FileName: {
-            if (FileOperationUtils::leftNameIsDuplicatedFileOfRightName(leftItem->m_info->displayName(), rightItem->m_info->displayName())) {
-                return FileOperationUtils::leftNameLesserThanRightName(leftItem->info()->displayName(), rightItem->info()->displayName());
-            }
-            if (m_use_default_name_sort_order) {
-                QString leftDisplayName = leftItem->m_info->displayName();
-                QString rightDisplayName = rightItem->m_info->displayName();
-
-                if(startWithChinese(leftDisplayName)&&!startWithChinese(rightDisplayName))
-                    return true;
-                else if(!startWithChinese(leftDisplayName)&&startWithChinese(rightDisplayName))
-                    return false;
-                else
-                    return comparer.compare(leftDisplayName, rightDisplayName) < 0;
-            }
-            //return leftItem->m_info->displayName().toLower() < rightItem->m_info->displayName().toLower();
-            return comparer.compare(leftItem->m_info->displayName(), rightItem->m_info->displayName()) < 0;
+            goto default_sort;
         }
         case FileItemModel::FileSize: {
-            return leftItem->m_info->size() < rightItem->m_info->size();
+            qDebug() << "FileSize:" <<leftItem->m_info->displayName()<<leftItem->m_info->size()
+                     <<rightItem->m_info->displayName()<<rightItem->m_info->size();
+            //fix refresh sort order change issue, use file name to compare, link to bug#92525
+            if (leftItem->m_info->size() == rightItem->m_info->size())
+            {
+                goto default_sort;
+            }
+            return leftItem->m_info->size() > rightItem->m_info->size();
         }
         case FileItemModel::FileType: {
-            return leftItem->m_info->fileType() < rightItem->m_info->fileType();
+            //fix refresh sort order change issue, use file name to compare, link to bug#92525
+            if (leftItem->m_info->fileType() == rightItem->m_info->fileType())
+            {
+                 goto default_sort;
+            }
+            return leftItem->m_info->fileType() > rightItem->m_info->fileType();
         }
         case FileItemModel::ModifiedDate: {
             //delete time sort in trash, fix bug#63093
             if (leftItem->uri().startsWith("trash://"))
-                return leftItem->m_info->deletionDate() < rightItem->m_info->deletionDate();
+            {
+                if (leftItem->m_info->deletionDate() == rightItem->m_info->deletionDate())
+                {
+                    goto default_sort;
+                }
+                return leftItem->m_info->deletionDate() > rightItem->m_info->deletionDate();
+            }
 
-            return leftItem->m_info->modifiedTime() < rightItem->m_info->modifiedTime();
+            //non trash files, use modifiedTime sort
+            if (leftItem->m_info->modifiedTime() == rightItem->m_info->modifiedTime())
+            {
+                goto default_sort;
+            }
+            return leftItem->m_info->modifiedTime() > rightItem->m_info->modifiedTime();
         }
         default:
             break;
         }
+
+default_sort:
+        //function was deprecated
+//        if (FileOperationUtils::leftNameIsDuplicatedFileOfRightName(leftItem->m_info->displayName(), rightItem->m_info->displayName())) {
+//            return FileOperationUtils::leftNameLesserThanRightName(leftItem->info()->displayName(), rightItem->info()->displayName());
+//        }
+
+        //when other sort value is the same, use sort by name way，link to bug#92525
+        //排序条件下的值相等时，使用名称进行排序，保持排序稳定，刷新后不改变, 关联bug#92525
+        QString leftDisplayName = leftItem->m_info->displayName();
+        QString rightDisplayName = rightItem->m_info->displayName();
+        if (m_use_default_name_sort_order) {
+            //fix chinese first sort wrong issue, link to bug#70836
+            //fix bug#97408,change indicator meanings
+            bool lesser = true;
+            if(startWithChinese(leftDisplayName) && ! startWithChinese(rightDisplayName)) {
+                // fix #103343
+                lesser = true;
+                if (sortOrder() == Qt::AscendingOrder)
+                    return lesser;
+                return !lesser;
+            }
+            else if(! startWithChinese(leftDisplayName) && startWithChinese(rightDisplayName)) {
+                lesser = false;
+                if (sortOrder() == Qt::AscendingOrder)
+                    return lesser;
+                return !lesser;
+            }
+            else
+                return comparer.compare(leftDisplayName, rightDisplayName) > 0;
+        }
+        return comparer.compare(leftDisplayName, rightDisplayName) > 0;
     }
 
     return QSortFilterProxyModel::lessThan(left, right);
@@ -187,6 +234,20 @@ bool FileItemProxyFilterSortModel::filterAcceptsRow(int sourceRow, const QModelI
         if (targetUri.startsWith("file:///media/") && targetUri.endsWith("/2691-6AB8"))
             return false;
 
+        //not show system orgin lost+found and sec_storage_data folder in DATA, fix bug#67084
+        /* not show system orgin lost+found and bbox_logs folder in file:///data, fix bug#104820、bug#105714 */
+        if(targetUri.endsWith("data/bbox_logs",Qt::CaseInsensitive))
+            return false;
+        if (targetUri.endsWith("data/lost+found",Qt::CaseInsensitive) || targetUri.endsWith("data/sec_storage_data",Qt::CaseInsensitive))
+        {
+            if (! item->m_info->canWrite() && ! item->m_info->canExecute())
+               return false;
+        }
+
+        //FIXME use display name to hide 839 MB disk
+        if (item->m_info->displayName().contains("839 MB"))
+            return false;
+
         //check the file info filter conditions
         //qDebug()<<"start filter conditions check"<<item->m_info->displayName()<<item->m_info->type();
         if (! checkFileTypeFilter(item->m_info->type()))
@@ -281,7 +342,8 @@ bool FileItemProxyFilterSortModel::checkFileNameFilter(const QString &displayNam
 
     for(auto key:m_file_name_list)
     {
-        if (displayName.contains(key))
+        //Filter criteria are not case sensitive. fix bug#92478
+        if (displayName.contains(key, Qt::CaseInsensitive))
             return true;
     }
 
@@ -340,7 +402,8 @@ bool FileItemProxyFilterSortModel::checkFileTypeFilter(QString type) const
         }
         case AUDIO:
         {
-            if (type.contains(Audio_Type))
+            //fix bug#121476, special audio type
+            if (type.contains(Audio_Type) || type.contains(Audio_Extend))
                 return true;
             break;
         }
@@ -348,7 +411,8 @@ bool FileItemProxyFilterSortModel::checkFileTypeFilter(QString type) const
         {
             //exclude classfied types, show the rest other types
             if (type != Folder_Type && ! type.contains(Image_Type) && ! type.contains(Video_Type)
-                    && ! type.contains(Text_Type) && !type.contains(Wps_Type) && ! type.contains(Audio_Type))
+                    && ! type.contains(Text_Type) && !type.contains(Wps_Type) && ! type.contains(Audio_Type)
+                    && ! type.contains(Audio_Extend))
                 return true;
             break;
         }
@@ -505,7 +569,7 @@ void FileItemProxyFilterSortModel::update()
 
 void FileItemProxyFilterSortModel::setShowHidden(bool showHidden)
 {
-    GlobalSettings::getInstance()->setValue(SHOW_HIDDEN_PREFERENCE, showHidden);
+    GlobalSettings::getInstance()->setGSettingValue(SHOW_HIDDEN_PREFERENCE, showHidden);
     m_show_hidden = showHidden;
     invalidateFilter();
 }
